@@ -30,7 +30,7 @@ sub make_files_writable {
 
 sub perl_scripts {
     return ('po4a-gettextize', 'po4a-updatepo', 'po4a-translate',
-            'po4a-normalize', 'po4a', 'scripts/msguntypot');
+            'po4a-normalize', 'po4a', 'msguntypot');
 }
 
 # Update po/bin/*.po files
@@ -126,7 +126,6 @@ sub ACTION_install {
 sub ACTION_dist {
     my ($self) = @_;
 
-    $ENV{PO4AFLAGS} ||= '--force';
     $self->depends_on('distcheck');
     $self->depends_on('test');
     $self->depends_on('binpo');
@@ -193,7 +192,7 @@ sub ACTION_man {
     copy ( File::Spec->catdir("doc", "po4a.7.pod"), $man7path) or die;
     foreach $file (perl_scripts()) {
         $file =~ m,([^/]*)$,;
-        copy($file, File::Spec->catdir($man1path, "$1.1p.pod")) or die;
+        copy($file, File::Spec->catdir($man1path, "$1.1p.pod")) or die "Cannot copy $file over";
     }
     foreach $file (@{$self->rscan_dir('lib',qr{\.pm$})}) {
         $file =~ m,([^/]*).pm$,;
@@ -238,13 +237,19 @@ sub ACTION_man {
     }
 
     # Install the manpages written in XML DocBook
-    foreach $file (qw(po4aman-display-po.xml po4apod-display-po.xml)) {
+    foreach $file (qw(po4a-display-man.xml po4a-display-pod.xml)) {
         copy ( File::Spec->catdir("share", "doc", $file), $man1path) or die;
     }
     foreach $file (@{$self->rscan_dir($manpath, qr{\.xml$})}) {
         if ($file =~ m,(.*/man(.))/([^/]*)\.xml$,) {
             my ($outdir, $section, $outfile) = ($1, $2, $3);
-            system("xsltproc -o $outdir/$outfile.$section --nonet http://docbook.sourceforge.net/release/xsl/current/manpages/docbook.xsl $file") and die;
+	    if (-e "/usr/share/xml/docbook/stylesheet/docbook-xsl/manpages/docbook.xsl") { # Location on Debian at least
+		print "Convert $outdir/$outfile.$section (local docbook.xsl file). ";
+		system("xsltproc -o $outdir/$outfile.$section --nonet /usr/share/xml/docbook/stylesheet/docbook-xsl/manpages/docbook.xsl $file") and die;
+	    } else { # Not found locally, use the XSL file online
+		print "Convert $outdir/$outfile.$section (online docbook.xsl file). ";
+		system("xsltproc -o $outdir/$outfile.$section --nonet http://docbook.sourceforge.net/release/xsl/current/manpages/docbook.xsl $file") and die;
+	    }
             system ("gzip -9 -f $outdir/$outfile.$section") and die;
         }
         unlink "$file" || die;
